@@ -1,10 +1,14 @@
+import pytest
 from tests.base import RemoteGefUnitTestGeneric
 from tests.utils import (
+    ARCH,
+    IN_GITHUB_ACTIONS,
     gdbserver_session,
 )
 
 
 class RegressionGdbserverConnection(RemoteGefUnitTestGeneric):
+    @pytest.mark.skipif(ARCH == "aarch64" and IN_GITHUB_ACTIONS, reason=f"Skipped for {ARCH} on CI")
     def test_can_establish_connection_to_gdbserver_again_after_disconnect(self):
         """Ensure that gdb can connect to a gdbserver again after disconnecting (PR #896)."""
         gdb = self._gdb
